#include <WScom.h>
#include <WSCfunctionList.h>
#include <WSCbase.h>

#include <WSDenv.h>

/**/

#include "MainWin.h"

#include "HeadLine.h"
#include "Url.h"
#include "Message.h"
#include "Misc.h"

#include "Sock.h"
#include "NewsThread.h"

/**/

const long gSkipArtMaxN = 1000;

/**/

